==> monica-3.7.0p2.tgz: www/monica/resources/lang/it/mail.php <==
<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [

    'subject_line' => 'Promemoria per :contact',
    'greetings' => 'Ciao :username',
    'want_reminded_of' => 'Volevi che ti ricordassi :reason',
    'for' => 'Per: :name',
    'comment' => 'Commento: :comment',
    'footer_contact_info' => 'Aggiungi, consulta, completa e cambia le informazioni di questo contatto:',
    'footer_contact_info2' => 'Apri il profilo di :name',
    'footer_contact_info2_link' => 'Apri il profilo di :name: :url',

    'notification_subject_line' => 'Hai un evento in programma',
    'notification_description' => 'Tra :count giorni (il :date), avverrà questo evento:',

    'stay_in_touch_subject_line' => 'Rimani in contatto con :name',
    'stay_in_touch_subject_description' => 'Volevi che ti ricordassi di rimanere in contatto con :name ogni giorno.|Volevi che ti ricordassi di rimanere in contatto con :name ogni :frequency giorni.',

    'notifications_whoops' => 'Ops!',
    'notifications_hello' => 'Ciao!',
    'notifications_regards' => 'Saluti',
    'notifications_footer' => 'Se hai problemi nel cliccare sul bottone ":actionText", copia e incolla il seguente indirizzo direttamente nel tuo browser web: [:actionURL](:actionURL)',
    'notifications_rights' => 'Tutti i diritti riservati',

    'confirmation_email_title' => 'Monica – Verifica Email',
    'confirmation_email_intro'=> 'Per verificare il tuo indirizzo email clicca il bottone qui sotto',
    'confirmation_email_button' => 'Verifica indirizzo email',
    'confirmation_email_bottom' => 'Se non hai creato un account, non è richiesta alcuna azione ulteriore.',

    'password_reset_title' => 'Monica – Reimposta la tua password',
    'password_reset_intro' => 'Hai ricevuto questa email perché dal tuo account é partita una richiesta di reimpostazione della password.',
    'password_reset_button' => 'Reimposta Password',
    'password_reset_expiration' => 'Il link per reimpostare la password scadrà tra :count minuti.',
    'password_reset_bottom' => 'Se non hai richiesto di reimpostare la password, non sono necessarie ulteriori azioni.',

    'invitation_title' => 'Monica – Sei stato invitato da :name',
    'invitation_intro' => 'Sei stato invitato da :name (:email) a usare Monica, un buon strumento per la gestione delle relazioni personali.',
    'invitation_link' => 'Per accettare l\'invito, clicca sul link sottostante:',
    'invitation_button' => 'Accetta l\'invito',
    'invitation_expiration' => 'Questo link scadrà tra :count giorni.',

    'export_title' => 'Your export is ready',
    'export_description' => 'You requested a data export on :date. It is now ready to download.',
    'export_download' => 'Download export',

];

==> monica-4.1.2p0.tgz: www/monica/resources/lang/it/mail.php <==
<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [

    'subject_line' => 'Promemoria per :contact',
    'greetings' => 'Ciao :username',
    'want_reminded_of' => 'Volevi che ti ricordassi :reason',
    'for' => 'Per: :name',
    'comment' => 'Commento: :comment',
    'footer_contact_info' => 'Aggiungi, consulta, completa e cambia le informazioni di questo contatto:',
    'footer_contact_info2' => 'Apri il profilo di :name',
    'footer_contact_info2_link' => 'Apri il profilo di :name: :url',

    'notification_subject_line' => 'Hai un evento in programma',
    'notification_description' => 'Tra :count giorni (il :date), avverrà questo evento:',

    'stay_in_touch_subject_line' => 'Rimani in contatto con :name',
    'stay_in_touch_subject_description' => 'Volevi che ti ricordassi di rimanere in contatto con :name ogni giorno.|Volevi che ti ricordassi di rimanere in contatto con :name ogni :frequency giorni.',

    'notifications_whoops' => 'Ops!',
    'notifications_hello' => 'Ciao!',
    'notifications_regards' => 'Saluti',
    'notifications_footer' => 'Se hai problemi nel cliccare sul bottone ":actionText", copia e incolla il seguente indirizzo direttamente nel tuo browser web: [:actionURL](:actionURL)',
    'notifications_rights' => 'Tutti i diritti riservati',

    'confirmation_email_title' => 'Monica – Verifica Email',
    'confirmation_email_intro'=> 'Per verificare il tuo indirizzo email clicca il bottone qui sotto',
    'confirmation_email_button' => 'Verifica indirizzo email',
    'confirmation_email_bottom' => 'Se non hai creato un account, non è richiesta alcuna azione ulteriore.',

    'password_reset_title' => 'Monica – Reimposta la tua password',
    'password_reset_intro' => 'Hai ricevuto questa email perché dal tuo account é partita una richiesta di reimpostazione della password.',
    'password_reset_button' => 'Reimposta Password',
    'password_reset_expiration' => 'Il link per reimpostare la password scadrà tra :count minuti.',
    'password_reset_bottom' => 'Se non hai richiesto di reimpostare la password, non sono necessarie ulteriori azioni.',

    'invitation_title' => 'Monica – Sei stato invitato da :name',
    'invitation_intro' => 'Sei stato invitato da :name (:email) a usare Monica, un buon strumento per la gestione delle relazioni personali.',
    'invitation_link' => 'Per accettare l\'invito, clicca sul link sottostante:',
    'invitation_button' => 'Accetta l\'invito',
    'invitation_expiration' => 'Questo link scadrà tra :count giorni.',

    'export_title' => 'L\'esportazione è pronta',
    'export_description' => 'Hai richiesto un\'esportazione di dati il :date. Ora è pronto per il download.',
    'export_download' => 'Scarica l\'esportazione',

];
